@@ -8,11 +8,16 @@ sub get_job_config {
     my $self = shift;
     my $params = shift;
     my $jobs = undef;
+    eval {
+        use XML::Simple;
+        use Template;
+    };
     if ($params->{Jobs}) {
         if (-f $params->{Jobs}) {
-            my $tt = new Template({EVAL_PERL => 1});
+            my $tt = Template->new();
             my $processed;
-            $tt->process($params->{Jobs}, $self, \$processed);
+            $tt->process($params->{Jobs}, $params, \$processed)
+                or die $tt->error;
             $jobs = XMLin($processed, KeyAttr=>{ name => 'name1'});
         }
         else {
@@ -22,6 +27,7 @@ sub get_job_config {
     else  {
         croak("Mandator Parameter Xml input file Jobs missing for JobsFromXML");
     }
+
     return $jobs->{Job};
 }
 1;
@@ -37,11 +43,6 @@ Schedule::Pluggable::Plugin::JobsFromXMLTemplate - Plugin Role for Schedule::Plu
 
 =item get_job_config
 
-get_job_config is the only method in this plugin and is returns the job config from and XML file
-It expects a mandatory hashref which has a key Jobs containing the name of a file which contains the xml job configuration.
-As the name suggests, the file is also processed by Template::Toolkit
-
-
 =back
 
 =cut
